@@ -21,7 +21,7 @@ import email.message
 import email.utils
 import unforward.emailclients
 import quopri
-from unforward.errors import NoForwardFoundError
+from unforward.errors import NoForwardFoundError, NoHTMLPayloadFound
 from pprint import pprint
 
 class Extractor:
@@ -52,7 +52,7 @@ class Extractor:
                         return self.extract_from_html(payload_string)
                     elif payload.get('content-type').startswith('multipart/alternative'):
                         return process_payload(payload.get_payload())
-                raise NotImplementedError("Did not find any payloads with text/html.")
+                raise NoHTMLPayloadFound("Did not find any payloads with text/html.")
             else:
                 payload_string = quopri.decodestring(payloads)
                 return self.extract_from_html(payload_string)
