@@ -16,6 +16,7 @@
 #
 
 import datetime
+import dateutil.tz
 
 examples =  [
                 {
@@ -23,7 +24,7 @@ examples =  [
                     "file" : "examples/outlook_express_forward.html",
                     "result" : {'sender' : 'laolaw@lao.on.ca',
                                 'body'   : '<p>Original Email</p>',
-                                'date'   : datetime.datetime(2014, 4, 17, 15, 39, 52)}
+                                'date'   : datetime.datetime(2014, 4, 17, 15, 39, 52, tzinfo = dateutil.tz.tzlocal())}
                 },
                 {
                     "client": ["gmail"],
@@ -58,7 +59,7 @@ examples =  [
                     "file" : "examples/iphone_forward.html",
                     "result" : {'sender' : 'dmz@ryerson.ca',
                                 'body'   : '<p>Original Email</p>',
-                                'date'   : datetime.datetime(2014, 4, 17, 12, 50, 56)}
+                                'date'   : datetime.datetime(2014, 4, 17, 12, 50, 56, tzinfo = dateutil.tz.tzlocal())}
                 },
                 {
                     "client": ["lotusnotes"],
